close all
% Define Elongation and strain data
Elongation = 0:24;
strain = Elongation / 100;

% resistance measurements, 1mm stretch per step
T1 = [6.4, 6.4, 6.4, 6.2, 6.2, 6.4, 6.5, 6.8, 6.8, 7.2, 7.4, 7.8, 8, 8.5, 8.8, 9.4, 9.8, 10.5, 11.4, 11.7, 13.2, 13.8, 14.8, 15.8, 16.6];
T2 = [8, 8.2, 8.2, 8.3, 8.4, 8.2, 8.6, 8.7, 8.9, 9.3, 9.8, 10.6, 11.1, 11.8, 12, 13.2, 13.6, 14.4, 15.6, 16.4, 17.8, 18.3, 19.6, 19.4, 21.7];
T3 = [8.8, 8.6, 8.8, 9.1, 9.1, 8.9, 9.2, 9.5, 9.8, 10.3, 10.9, 11.9, 13, 13.6, 15.8, 14.8, 16.6, 15.7, 18, 17.5, 19.6, 20.4, 19.9, 20.6, 21];
T4 = [9.7, 9.5, 9.4, 9.5, 9.6, 9.8, 10.1, 10.6, 11.1, 11.3, 12, 13.8, 13.9, 14.4, 15, 15.6, 16, 16.9, 17.3, 18.3, 19.1, 21.2, 22.1, 23.5, 23.4];
T5 = [8.1, 8, 8.2, 8.2, 8.3, 8.6, 8.9, 9, 9.9, 10, 10.5, 11.1, 11.6, 12.4, 13.2, 14.1, 15.2, 16.1, 17, 17.6, 19.8, 21, 21.6, 22.5, 23.5];

% Calculate mean and standard deviation across T2-T5
Amean = mean([T2; T3; T4; T5], 1);
Astd = std([T2; T3; T4; T5], 1);

% Set up figure properties
figure('Color', 'white', 'Units', 'normalized', 'Position', [0.5, 0.5, 0.35, 0.39]);
hold on

% Plot T1
plot(strain, T1, 'LineWidth', 3, 'Color', 'k');

% Fill area for mean  std
fill([strain, fliplr(strain)], [Amean + Astd, fliplr(Amean - Astd)], [225/255, 225/255, 225/255], 'EdgeColor', 'none');

% Highlight points for slope and gauge factor calculation
DOI = Amean([1, 5, 9, 13, 17, 21, 25]);
y_points = [1, 5, 9, 13, 17, 21, 25];
GF = zeros(1, 6);

for i = 1:6
    i
    DOI(i + 1)
    DOI(i)
    delta_R = DOI(i + 1) - DOI(i)
    GF(i) = round((delta_R / DOI(i)) / 0.04, 2) % Gauge factor calculation
    
    % Add text annotation for Gauge Factor
  text((0.05*(i-1))-0.01*(i-1)+0.01,T1DOI(i+1)-0.25, strcat([num2str(GF(i))]),'FontSize',15)
end

% Plot mean line with dashed style
plot(strain, Amean, '--', 'Color', [0.2, 0.2, 0.2], 'LineWidth', 3);

% Label axes
xlabel('Strain');
ylabel('Resistance (\Omega)');
ax = gca;
ax.LineWidth = 1;
ax.FontSize = 32;
xlim([-0.0003, 0.2403]);
ylim([5, 24]);

% Add vertical lines at specific strain points
for i = 1:5
    xline(0.04 * i, '--', 'Color', [0.5, 0.5, 0.5]);
end

% Add legend
legend('Initial stretch', '\mu  \sigma', '\mu', 'Location', 'northwest', 'FontSize', 20);
xticks(0:0.04:0.24);
set(gca, 'FontSize', 15); % Increase font size of axis ticks and labels

box on
hold off
